<?php
declare(strict_types = 1);

namespace Dagr\Tzdb;

final class Catalog
{
    public const LINKS = [
        'africa/bamako' => 'africa/abidjan',
        'africa/banjul' => 'africa/abidjan',
        'africa/conakry' => 'africa/abidjan',
        'africa/dakar' => 'africa/abidjan',
        'africa/freetown' => 'africa/abidjan',
        'africa/lome' => 'africa/abidjan',
        'africa/nouakchott' => 'africa/abidjan',
        'africa/ouagadougou' => 'africa/abidjan',
        'africa/sao_tome' => 'africa/abidjan',
        'atlantic/st_helena' => 'africa/abidjan',
        'africa/addis_ababa' => 'africa/nairobi',
        'africa/asmara' => 'africa/nairobi',
        'africa/dar_es_salaam' => 'africa/nairobi',
        'africa/djibouti' => 'africa/nairobi',
        'africa/kampala' => 'africa/nairobi',
        'africa/mogadishu' => 'africa/nairobi',
        'indian/antananarivo' => 'africa/nairobi',
        'indian/comoro' => 'africa/nairobi',
        'indian/mayotte' => 'africa/nairobi',
        'africa/blantyre' => 'africa/maputo',
        'africa/bujumbura' => 'africa/maputo',
        'africa/gaborone' => 'africa/maputo',
        'africa/harare' => 'africa/maputo',
        'africa/kigali' => 'africa/maputo',
        'africa/lubumbashi' => 'africa/maputo',
        'africa/lusaka' => 'africa/maputo',
        'africa/bangui' => 'africa/lagos',
        'africa/brazzaville' => 'africa/lagos',
        'africa/douala' => 'africa/lagos',
        'africa/kinshasa' => 'africa/lagos',
        'africa/libreville' => 'africa/lagos',
        'africa/luanda' => 'africa/lagos',
        'africa/malabo' => 'africa/lagos',
        'africa/niamey' => 'africa/lagos',
        'africa/porto-novo' => 'africa/lagos',
        'africa/maseru' => 'africa/johannesburg',
        'africa/mbabane' => 'africa/johannesburg',
        'africa/juba' => 'africa/khartoum',
        'europe/nicosia' => 'asia/nicosia',
        'asia/bahrain' => 'asia/qatar',
        'asia/aden' => 'asia/riyadh',
        'asia/kuwait' => 'asia/riyadh',
        'asia/phnom_penh' => 'asia/bangkok',
        'asia/vientiane' => 'asia/bangkok',
        'asia/muscat' => 'asia/dubai',
        'pacific/saipan' => 'pacific/guam',
        'antarctica/mcmurdo' => 'pacific/auckland',
        'pacific/midway' => 'pacific/pago_pago',
        'europe/jersey' => 'europe/london',
        'europe/guernsey' => 'europe/london',
        'europe/isle_of_man' => 'europe/london',
        'europe/mariehamn' => 'europe/helsinki',
        'europe/busingen' => 'europe/zurich',
        'europe/vatican' => 'europe/rome',
        'europe/san_marino' => 'europe/rome',
        'europe/vaduz' => 'europe/zurich',
        'arctic/longyearbyen' => 'europe/oslo',
        'europe/ljubljana' => 'europe/belgrade',
        'europe/podgorica' => 'europe/belgrade',
        'europe/sarajevo' => 'europe/belgrade',
        'europe/skopje' => 'europe/belgrade',
        'europe/zagreb' => 'europe/belgrade',
        'europe/bratislava' => 'europe/prague',
        'asia/istanbul' => 'europe/istanbul',
        'america/cayman' => 'america/panama',
        'us/pacific-new' => 'america/los_angeles',
        'america/aruba' => 'america/curacao',
        'america/lower_princes' => 'america/curacao',
        'america/kralendijk' => 'america/curacao',
        'america/anguilla' => 'america/port_of_spain',
        'america/antigua' => 'america/port_of_spain',
        'america/dominica' => 'america/port_of_spain',
        'america/grenada' => 'america/port_of_spain',
        'america/guadeloupe' => 'america/port_of_spain',
        'america/marigot' => 'america/port_of_spain',
        'america/montserrat' => 'america/port_of_spain',
        'america/st_barthelemy' => 'america/port_of_spain',
        'america/st_kitts' => 'america/port_of_spain',
        'america/st_lucia' => 'america/port_of_spain',
        'america/st_thomas' => 'america/port_of_spain',
        'america/st_vincent' => 'america/port_of_spain',
        'america/tortola' => 'america/port_of_spain',
        'africa/asmera' => 'africa/nairobi',
        'africa/timbuktu' => 'africa/abidjan',
        'america/argentina/comodrivadavia' => 'america/argentina/catamarca',
        'america/atka' => 'america/adak',
        'america/buenos_aires' => 'america/argentina/buenos_aires',
        'america/catamarca' => 'america/argentina/catamarca',
        'america/coral_harbour' => 'america/atikokan',
        'america/cordoba' => 'america/argentina/cordoba',
        'america/ensenada' => 'america/tijuana',
        'america/fort_wayne' => 'america/indiana/indianapolis',
        'america/indianapolis' => 'america/indiana/indianapolis',
        'america/jujuy' => 'america/argentina/jujuy',
        'america/knox_in' => 'america/indiana/knox',
        'america/louisville' => 'america/kentucky/louisville',
        'america/mendoza' => 'america/argentina/mendoza',
        'america/montreal' => 'america/toronto',
        'america/porto_acre' => 'america/rio_branco',
        'america/rosario' => 'america/argentina/cordoba',
        'america/santa_isabel' => 'america/tijuana',
        'america/shiprock' => 'america/denver',
        'america/virgin' => 'america/port_of_spain',
        'antarctica/south_pole' => 'pacific/auckland',
        'asia/ashkhabad' => 'asia/ashgabat',
        'asia/calcutta' => 'asia/kolkata',
        'asia/chongqing' => 'asia/shanghai',
        'asia/chungking' => 'asia/shanghai',
        'asia/dacca' => 'asia/dhaka',
        'asia/harbin' => 'asia/shanghai',
        'asia/kashgar' => 'asia/urumqi',
        'asia/katmandu' => 'asia/kathmandu',
        'asia/macao' => 'asia/macau',
        'asia/rangoon' => 'asia/yangon',
        'asia/saigon' => 'asia/ho_chi_minh',
        'asia/tel_aviv' => 'asia/jerusalem',
        'asia/thimbu' => 'asia/thimphu',
        'asia/ujung_pandang' => 'asia/makassar',
        'asia/ulan_bator' => 'asia/ulaanbaatar',
        'atlantic/faeroe' => 'atlantic/faroe',
        'atlantic/jan_mayen' => 'europe/oslo',
        'australia/act' => 'australia/sydney',
        'australia/canberra' => 'australia/sydney',
        'australia/lhi' => 'australia/lord_howe',
        'australia/nsw' => 'australia/sydney',
        'australia/north' => 'australia/darwin',
        'australia/queensland' => 'australia/brisbane',
        'australia/south' => 'australia/adelaide',
        'australia/tasmania' => 'australia/hobart',
        'australia/victoria' => 'australia/melbourne',
        'australia/west' => 'australia/perth',
        'australia/yancowinna' => 'australia/broken_hill',
        'brazil/acre' => 'america/rio_branco',
        'brazil/denoronha' => 'america/noronha',
        'brazil/east' => 'america/sao_paulo',
        'brazil/west' => 'america/manaus',
        'canada/atlantic' => 'america/halifax',
        'canada/central' => 'america/winnipeg',
        'canada/east-saskatchewan' => 'america/regina',
        'canada/eastern' => 'america/toronto',
        'canada/mountain' => 'america/edmonton',
        'canada/newfoundland' => 'america/st_johns',
        'canada/pacific' => 'america/vancouver',
        'canada/saskatchewan' => 'america/regina',
        'canada/yukon' => 'america/whitehorse',
        'chile/continental' => 'america/santiago',
        'chile/easterisland' => 'pacific/easter',
        'cuba' => 'america/havana',
        'egypt' => 'africa/cairo',
        'eire' => 'europe/dublin',
        'europe/belfast' => 'europe/london',
        'europe/tiraspol' => 'europe/chisinau',
        'gb' => 'europe/london',
        'gb-eire' => 'europe/london',
        'gmt+0' => 'etc/gmt',
        'gmt-0' => 'etc/gmt',
        'gmt0' => 'etc/gmt',
        'greenwich' => 'etc/gmt',
        'hongkong' => 'asia/hong_kong',
        'iceland' => 'atlantic/reykjavik',
        'iran' => 'asia/tehran',
        'israel' => 'asia/jerusalem',
        'jamaica' => 'america/jamaica',
        'japan' => 'asia/tokyo',
        'kwajalein' => 'pacific/kwajalein',
        'libya' => 'africa/tripoli',
        'mexico/bajanorte' => 'america/tijuana',
        'mexico/bajasur' => 'america/mazatlan',
        'mexico/general' => 'america/mexico_city',
        'nz' => 'pacific/auckland',
        'nz-chat' => 'pacific/chatham',
        'navajo' => 'america/denver',
        'prc' => 'asia/shanghai',
        'pacific/johnston' => 'pacific/honolulu',
        'pacific/ponape' => 'pacific/pohnpei',
        'pacific/samoa' => 'pacific/pago_pago',
        'pacific/truk' => 'pacific/chuuk',
        'pacific/yap' => 'pacific/chuuk',
        'poland' => 'europe/warsaw',
        'portugal' => 'europe/lisbon',
        'roc' => 'asia/taipei',
        'rok' => 'asia/seoul',
        'singapore' => 'asia/singapore',
        'turkey' => 'europe/istanbul',
        'uct' => 'etc/uct',
        'us/alaska' => 'america/anchorage',
        'us/aleutian' => 'america/adak',
        'us/arizona' => 'america/phoenix',
        'us/central' => 'america/chicago',
        'us/east-indiana' => 'america/indiana/indianapolis',
        'us/eastern' => 'america/new_york',
        'us/hawaii' => 'pacific/honolulu',
        'us/indiana-starke' => 'america/indiana/knox',
        'us/michigan' => 'america/detroit',
        'us/mountain' => 'america/denver',
        'us/pacific' => 'america/los_angeles',
        'us/samoa' => 'pacific/pago_pago',
        'utc' => 'etc/utc',
        'universal' => 'etc/utc',
        'w-su' => 'europe/moscow',
        'zulu' => 'etc/utc',
        'gmt' => 'etc/gmt',
        'etc/universal' => 'etc/utc',
        'etc/zulu' => 'etc/utc',
        'etc/greenwich' => 'etc/gmt',
        'etc/gmt-0' => 'etc/gmt',
        'etc/gmt+0' => 'etc/gmt',
        'etc/gmt0' => 'etc/gmt',
    ];
    public const ZONES = [
        'africa/algiers' => Zone\Africa\Algiers::class,
        'atlantic/cape_verde' => Zone\Atlantic\CapeVerde::class,
        'africa/ndjamena' => Zone\Africa\Ndjamena::class,
        'africa/abidjan' => Zone\Africa\Abidjan::class,
        'africa/cairo' => Zone\Africa\Cairo::class,
        'africa/accra' => Zone\Africa\Accra::class,
        'africa/bissau' => Zone\Africa\Bissau::class,
        'africa/nairobi' => Zone\Africa\Nairobi::class,
        'africa/monrovia' => Zone\Africa\Monrovia::class,
        'africa/tripoli' => Zone\Africa\Tripoli::class,
        'indian/mauritius' => Zone\Indian\Mauritius::class,
        'africa/casablanca' => Zone\Africa\Casablanca::class,
        'africa/el_aaiun' => Zone\Africa\ElAaiun::class,
        'africa/maputo' => Zone\Africa\Maputo::class,
        'africa/windhoek' => Zone\Africa\Windhoek::class,
        'africa/lagos' => Zone\Africa\Lagos::class,
        'indian/reunion' => Zone\Indian\Reunion::class,
        'indian/mahe' => Zone\Indian\Mahe::class,
        'africa/johannesburg' => Zone\Africa\Johannesburg::class,
        'africa/khartoum' => Zone\Africa\Khartoum::class,
        'africa/tunis' => Zone\Africa\Tunis::class,
        'antarctica/casey' => Zone\Antarctica\Casey::class,
        'antarctica/davis' => Zone\Antarctica\Davis::class,
        'antarctica/mawson' => Zone\Antarctica\Mawson::class,
        'indian/kerguelen' => Zone\Indian\Kerguelen::class,
        'antarctica/dumontdurville' => Zone\Antarctica\DumontDUrville::class,
        'antarctica/syowa' => Zone\Antarctica\Syowa::class,
        'antarctica/troll' => Zone\Antarctica\Troll::class,
        'antarctica/vostok' => Zone\Antarctica\Vostok::class,
        'antarctica/rothera' => Zone\Antarctica\Rothera::class,
        'asia/kabul' => Zone\Asia\Kabul::class,
        'asia/yerevan' => Zone\Asia\Yerevan::class,
        'asia/baku' => Zone\Asia\Baku::class,
        'asia/dhaka' => Zone\Asia\Dhaka::class,
        'asia/thimphu' => Zone\Asia\Thimphu::class,
        'indian/chagos' => Zone\Indian\Chagos::class,
        'asia/brunei' => Zone\Asia\Brunei::class,
        'asia/yangon' => Zone\Asia\Yangon::class,
        'asia/shanghai' => Zone\Asia\Shanghai::class,
        'asia/urumqi' => Zone\Asia\Urumqi::class,
        'asia/hong_kong' => Zone\Asia\HongKong::class,
        'asia/taipei' => Zone\Asia\Taipei::class,
        'asia/macau' => Zone\Asia\Macau::class,
        'asia/nicosia' => Zone\Asia\Nicosia::class,
        'asia/famagusta' => Zone\Asia\Famagusta::class,
        'asia/tbilisi' => Zone\Asia\Tbilisi::class,
        'asia/dili' => Zone\Asia\Dili::class,
        'asia/kolkata' => Zone\Asia\Kolkata::class,
        'asia/jakarta' => Zone\Asia\Jakarta::class,
        'asia/pontianak' => Zone\Asia\Pontianak::class,
        'asia/makassar' => Zone\Asia\Makassar::class,
        'asia/jayapura' => Zone\Asia\Jayapura::class,
        'asia/tehran' => Zone\Asia\Tehran::class,
        'asia/baghdad' => Zone\Asia\Baghdad::class,
        'asia/jerusalem' => Zone\Asia\Jerusalem::class,
        'asia/tokyo' => Zone\Asia\Tokyo::class,
        'asia/amman' => Zone\Asia\Amman::class,
        'asia/almaty' => Zone\Asia\Almaty::class,
        'asia/qyzylorda' => Zone\Asia\Qyzylorda::class,
        'asia/aqtobe' => Zone\Asia\Aqtobe::class,
        'asia/aqtau' => Zone\Asia\Aqtau::class,
        'asia/atyrau' => Zone\Asia\Atyrau::class,
        'asia/oral' => Zone\Asia\Oral::class,
        'asia/bishkek' => Zone\Asia\Bishkek::class,
        'asia/seoul' => Zone\Asia\Seoul::class,
        'asia/pyongyang' => Zone\Asia\Pyongyang::class,
        'asia/beirut' => Zone\Asia\Beirut::class,
        'asia/kuala_lumpur' => Zone\Asia\KualaLumpur::class,
        'asia/kuching' => Zone\Asia\Kuching::class,
        'indian/maldives' => Zone\Indian\Maldives::class,
        'asia/hovd' => Zone\Asia\Hovd::class,
        'asia/ulaanbaatar' => Zone\Asia\Ulaanbaatar::class,
        'asia/choibalsan' => Zone\Asia\Choibalsan::class,
        'asia/kathmandu' => Zone\Asia\Kathmandu::class,
        'asia/karachi' => Zone\Asia\Karachi::class,
        'asia/gaza' => Zone\Asia\Gaza::class,
        'asia/hebron' => Zone\Asia\Hebron::class,
        'asia/manila' => Zone\Asia\Manila::class,
        'asia/qatar' => Zone\Asia\Qatar::class,
        'asia/riyadh' => Zone\Asia\Riyadh::class,
        'asia/singapore' => Zone\Asia\Singapore::class,
        'asia/colombo' => Zone\Asia\Colombo::class,
        'asia/damascus' => Zone\Asia\Damascus::class,
        'asia/dushanbe' => Zone\Asia\Dushanbe::class,
        'asia/bangkok' => Zone\Asia\Bangkok::class,
        'asia/ashgabat' => Zone\Asia\Ashgabat::class,
        'asia/dubai' => Zone\Asia\Dubai::class,
        'asia/samarkand' => Zone\Asia\Samarkand::class,
        'asia/tashkent' => Zone\Asia\Tashkent::class,
        'asia/ho_chi_minh' => Zone\Asia\HoChiMinh::class,
        'australia/darwin' => Zone\Australia\Darwin::class,
        'australia/perth' => Zone\Australia\Perth::class,
        'australia/eucla' => Zone\Australia\Eucla::class,
        'australia/brisbane' => Zone\Australia\Brisbane::class,
        'australia/lindeman' => Zone\Australia\Lindeman::class,
        'australia/adelaide' => Zone\Australia\Adelaide::class,
        'australia/hobart' => Zone\Australia\Hobart::class,
        'australia/currie' => Zone\Australia\Currie::class,
        'australia/melbourne' => Zone\Australia\Melbourne::class,
        'australia/sydney' => Zone\Australia\Sydney::class,
        'australia/broken_hill' => Zone\Australia\BrokenHill::class,
        'australia/lord_howe' => Zone\Australia\LordHowe::class,
        'antarctica/macquarie' => Zone\Antarctica\Macquarie::class,
        'indian/christmas' => Zone\Indian\Christmas::class,
        'indian/cocos' => Zone\Indian\Cocos::class,
        'pacific/fiji' => Zone\Pacific\Fiji::class,
        'pacific/gambier' => Zone\Pacific\Gambier::class,
        'pacific/marquesas' => Zone\Pacific\Marquesas::class,
        'pacific/tahiti' => Zone\Pacific\Tahiti::class,
        'pacific/guam' => Zone\Pacific\Guam::class,
        'pacific/tarawa' => Zone\Pacific\Tarawa::class,
        'pacific/enderbury' => Zone\Pacific\Enderbury::class,
        'pacific/kiritimati' => Zone\Pacific\Kiritimati::class,
        'pacific/majuro' => Zone\Pacific\Majuro::class,
        'pacific/kwajalein' => Zone\Pacific\Kwajalein::class,
        'pacific/chuuk' => Zone\Pacific\Chuuk::class,
        'pacific/pohnpei' => Zone\Pacific\Pohnpei::class,
        'pacific/kosrae' => Zone\Pacific\Kosrae::class,
        'pacific/nauru' => Zone\Pacific\Nauru::class,
        'pacific/noumea' => Zone\Pacific\Noumea::class,
        'pacific/auckland' => Zone\Pacific\Auckland::class,
        'pacific/chatham' => Zone\Pacific\Chatham::class,
        'pacific/rarotonga' => Zone\Pacific\Rarotonga::class,
        'pacific/niue' => Zone\Pacific\Niue::class,
        'pacific/norfolk' => Zone\Pacific\Norfolk::class,
        'pacific/palau' => Zone\Pacific\Palau::class,
        'pacific/port_moresby' => Zone\Pacific\PortMoresby::class,
        'pacific/bougainville' => Zone\Pacific\Bougainville::class,
        'pacific/pitcairn' => Zone\Pacific\Pitcairn::class,
        'pacific/pago_pago' => Zone\Pacific\PagoPago::class,
        'pacific/apia' => Zone\Pacific\Apia::class,
        'pacific/guadalcanal' => Zone\Pacific\Guadalcanal::class,
        'pacific/fakaofo' => Zone\Pacific\Fakaofo::class,
        'pacific/tongatapu' => Zone\Pacific\Tongatapu::class,
        'pacific/funafuti' => Zone\Pacific\Funafuti::class,
        'pacific/wake' => Zone\Pacific\Wake::class,
        'pacific/efate' => Zone\Pacific\Efate::class,
        'pacific/wallis' => Zone\Pacific\Wallis::class,
        'europe/london' => Zone\Europe\London::class,
        'europe/dublin' => Zone\Europe\Dublin::class,
        'wet' => Zone\WET::class,
        'cet' => Zone\CET::class,
        'met' => Zone\MET::class,
        'eet' => Zone\EET::class,
        'europe/tirane' => Zone\Europe\Tirane::class,
        'europe/andorra' => Zone\Europe\Andorra::class,
        'europe/vienna' => Zone\Europe\Vienna::class,
        'europe/minsk' => Zone\Europe\Minsk::class,
        'europe/brussels' => Zone\Europe\Brussels::class,
        'europe/sofia' => Zone\Europe\Sofia::class,
        'europe/prague' => Zone\Europe\Prague::class,
        'europe/copenhagen' => Zone\Europe\Copenhagen::class,
        'atlantic/faroe' => Zone\Atlantic\Faroe::class,
        'america/danmarkshavn' => Zone\America\Danmarkshavn::class,
        'america/scoresbysund' => Zone\America\Scoresbysund::class,
        'america/godthab' => Zone\America\Godthab::class,
        'america/thule' => Zone\America\Thule::class,
        'europe/tallinn' => Zone\Europe\Tallinn::class,
        'europe/helsinki' => Zone\Europe\Helsinki::class,
        'europe/paris' => Zone\Europe\Paris::class,
        'europe/berlin' => Zone\Europe\Berlin::class,
        'europe/gibraltar' => Zone\Europe\Gibraltar::class,
        'europe/athens' => Zone\Europe\Athens::class,
        'europe/budapest' => Zone\Europe\Budapest::class,
        'atlantic/reykjavik' => Zone\Atlantic\Reykjavik::class,
        'europe/rome' => Zone\Europe\Rome::class,
        'europe/riga' => Zone\Europe\Riga::class,
        'europe/vilnius' => Zone\Europe\Vilnius::class,
        'europe/luxembourg' => Zone\Europe\Luxembourg::class,
        'europe/malta' => Zone\Europe\Malta::class,
        'europe/chisinau' => Zone\Europe\Chisinau::class,
        'europe/monaco' => Zone\Europe\Monaco::class,
        'europe/amsterdam' => Zone\Europe\Amsterdam::class,
        'europe/oslo' => Zone\Europe\Oslo::class,
        'europe/warsaw' => Zone\Europe\Warsaw::class,
        'europe/lisbon' => Zone\Europe\Lisbon::class,
        'atlantic/azores' => Zone\Atlantic\Azores::class,
        'atlantic/madeira' => Zone\Atlantic\Madeira::class,
        'europe/bucharest' => Zone\Europe\Bucharest::class,
        'europe/kaliningrad' => Zone\Europe\Kaliningrad::class,
        'europe/moscow' => Zone\Europe\Moscow::class,
        'europe/simferopol' => Zone\Europe\Simferopol::class,
        'europe/astrakhan' => Zone\Europe\Astrakhan::class,
        'europe/volgograd' => Zone\Europe\Volgograd::class,
        'europe/saratov' => Zone\Europe\Saratov::class,
        'europe/kirov' => Zone\Europe\Kirov::class,
        'europe/samara' => Zone\Europe\Samara::class,
        'europe/ulyanovsk' => Zone\Europe\Ulyanovsk::class,
        'asia/yekaterinburg' => Zone\Asia\Yekaterinburg::class,
        'asia/omsk' => Zone\Asia\Omsk::class,
        'asia/barnaul' => Zone\Asia\Barnaul::class,
        'asia/novosibirsk' => Zone\Asia\Novosibirsk::class,
        'asia/tomsk' => Zone\Asia\Tomsk::class,
        'asia/novokuznetsk' => Zone\Asia\Novokuznetsk::class,
        'asia/krasnoyarsk' => Zone\Asia\Krasnoyarsk::class,
        'asia/irkutsk' => Zone\Asia\Irkutsk::class,
        'asia/chita' => Zone\Asia\Chita::class,
        'asia/yakutsk' => Zone\Asia\Yakutsk::class,
        'asia/vladivostok' => Zone\Asia\Vladivostok::class,
        'asia/khandyga' => Zone\Asia\Khandyga::class,
        'asia/sakhalin' => Zone\Asia\Sakhalin::class,
        'asia/magadan' => Zone\Asia\Magadan::class,
        'asia/srednekolymsk' => Zone\Asia\Srednekolymsk::class,
        'asia/ust-nera' => Zone\Asia\UstMinusNera::class,
        'asia/kamchatka' => Zone\Asia\Kamchatka::class,
        'asia/anadyr' => Zone\Asia\Anadyr::class,
        'europe/belgrade' => Zone\Europe\Belgrade::class,
        'europe/madrid' => Zone\Europe\Madrid::class,
        'africa/ceuta' => Zone\Africa\Ceuta::class,
        'atlantic/canary' => Zone\Atlantic\Canary::class,
        'europe/stockholm' => Zone\Europe\Stockholm::class,
        'europe/zurich' => Zone\Europe\Zurich::class,
        'europe/istanbul' => Zone\Europe\Istanbul::class,
        'europe/kiev' => Zone\Europe\Kiev::class,
        'europe/uzhgorod' => Zone\Europe\Uzhgorod::class,
        'europe/zaporozhye' => Zone\Europe\Zaporozhye::class,
        'est' => Zone\EST::class,
        'mst' => Zone\MST::class,
        'hst' => Zone\HST::class,
        'est5edt' => Zone\EST5EDT::class,
        'cst6cdt' => Zone\CST6CDT::class,
        'mst7mdt' => Zone\MST7MDT::class,
        'pst8pdt' => Zone\PST8PDT::class,
        'america/new_york' => Zone\America\NewYork::class,
        'america/chicago' => Zone\America\Chicago::class,
        'america/north_dakota/center' => Zone\America\NorthDakota\Center::class,
        'america/north_dakota/new_salem' => Zone\America\NorthDakota\NewSalem::class,
        'america/north_dakota/beulah' => Zone\America\NorthDakota\Beulah::class,
        'america/denver' => Zone\America\Denver::class,
        'america/los_angeles' => Zone\America\LosAngeles::class,
        'america/juneau' => Zone\America\Juneau::class,
        'america/sitka' => Zone\America\Sitka::class,
        'america/metlakatla' => Zone\America\Metlakatla::class,
        'america/yakutat' => Zone\America\Yakutat::class,
        'america/anchorage' => Zone\America\Anchorage::class,
        'america/nome' => Zone\America\Nome::class,
        'america/adak' => Zone\America\Adak::class,
        'pacific/honolulu' => Zone\Pacific\Honolulu::class,
        'america/phoenix' => Zone\America\Phoenix::class,
        'america/boise' => Zone\America\Boise::class,
        'america/indiana/indianapolis' => Zone\America\Indiana\Indianapolis::class,
        'america/indiana/marengo' => Zone\America\Indiana\Marengo::class,
        'america/indiana/vincennes' => Zone\America\Indiana\Vincennes::class,
        'america/indiana/tell_city' => Zone\America\Indiana\TellCity::class,
        'america/indiana/petersburg' => Zone\America\Indiana\Petersburg::class,
        'america/indiana/knox' => Zone\America\Indiana\Knox::class,
        'america/indiana/winamac' => Zone\America\Indiana\Winamac::class,
        'america/indiana/vevay' => Zone\America\Indiana\Vevay::class,
        'america/kentucky/louisville' => Zone\America\Kentucky\Louisville::class,
        'america/kentucky/monticello' => Zone\America\Kentucky\Monticello::class,
        'america/detroit' => Zone\America\Detroit::class,
        'america/menominee' => Zone\America\Menominee::class,
        'america/st_johns' => Zone\America\StJohns::class,
        'america/goose_bay' => Zone\America\GooseBay::class,
        'america/halifax' => Zone\America\Halifax::class,
        'america/glace_bay' => Zone\America\GlaceBay::class,
        'america/moncton' => Zone\America\Moncton::class,
        'america/blanc-sablon' => Zone\America\BlancMinusSablon::class,
        'america/toronto' => Zone\America\Toronto::class,
        'america/thunder_bay' => Zone\America\ThunderBay::class,
        'america/nipigon' => Zone\America\Nipigon::class,
        'america/rainy_river' => Zone\America\RainyRiver::class,
        'america/atikokan' => Zone\America\Atikokan::class,
        'america/winnipeg' => Zone\America\Winnipeg::class,
        'america/regina' => Zone\America\Regina::class,
        'america/swift_current' => Zone\America\SwiftCurrent::class,
        'america/edmonton' => Zone\America\Edmonton::class,
        'america/vancouver' => Zone\America\Vancouver::class,
        'america/dawson_creek' => Zone\America\DawsonCreek::class,
        'america/fort_nelson' => Zone\America\FortNelson::class,
        'america/creston' => Zone\America\Creston::class,
        'america/pangnirtung' => Zone\America\Pangnirtung::class,
        'america/iqaluit' => Zone\America\Iqaluit::class,
        'america/resolute' => Zone\America\Resolute::class,
        'america/rankin_inlet' => Zone\America\RankinInlet::class,
        'america/cambridge_bay' => Zone\America\CambridgeBay::class,
        'america/yellowknife' => Zone\America\Yellowknife::class,
        'america/inuvik' => Zone\America\Inuvik::class,
        'america/whitehorse' => Zone\America\Whitehorse::class,
        'america/dawson' => Zone\America\Dawson::class,
        'america/cancun' => Zone\America\Cancun::class,
        'america/merida' => Zone\America\Merida::class,
        'america/matamoros' => Zone\America\Matamoros::class,
        'america/monterrey' => Zone\America\Monterrey::class,
        'america/mexico_city' => Zone\America\MexicoCity::class,
        'america/ojinaga' => Zone\America\Ojinaga::class,
        'america/chihuahua' => Zone\America\Chihuahua::class,
        'america/hermosillo' => Zone\America\Hermosillo::class,
        'america/mazatlan' => Zone\America\Mazatlan::class,
        'america/bahia_banderas' => Zone\America\BahiaBanderas::class,
        'america/tijuana' => Zone\America\Tijuana::class,
        'america/nassau' => Zone\America\Nassau::class,
        'america/barbados' => Zone\America\Barbados::class,
        'america/belize' => Zone\America\Belize::class,
        'atlantic/bermuda' => Zone\Atlantic\Bermuda::class,
        'america/costa_rica' => Zone\America\CostaRica::class,
        'america/havana' => Zone\America\Havana::class,
        'america/santo_domingo' => Zone\America\SantoDomingo::class,
        'america/el_salvador' => Zone\America\ElSalvador::class,
        'america/guatemala' => Zone\America\Guatemala::class,
        'america/port-au-prince' => Zone\America\PortMinusauMinusPrince::class,
        'america/tegucigalpa' => Zone\America\Tegucigalpa::class,
        'america/jamaica' => Zone\America\Jamaica::class,
        'america/martinique' => Zone\America\Martinique::class,
        'america/managua' => Zone\America\Managua::class,
        'america/panama' => Zone\America\Panama::class,
        'america/puerto_rico' => Zone\America\PuertoRico::class,
        'america/miquelon' => Zone\America\Miquelon::class,
        'america/grand_turk' => Zone\America\GrandTurk::class,
        'america/argentina/buenos_aires' => Zone\America\Argentina\BuenosAires::class,
        'america/argentina/cordoba' => Zone\America\Argentina\Cordoba::class,
        'america/argentina/salta' => Zone\America\Argentina\Salta::class,
        'america/argentina/tucuman' => Zone\America\Argentina\Tucuman::class,
        'america/argentina/la_rioja' => Zone\America\Argentina\LaRioja::class,
        'america/argentina/san_juan' => Zone\America\Argentina\SanJuan::class,
        'america/argentina/jujuy' => Zone\America\Argentina\Jujuy::class,
        'america/argentina/catamarca' => Zone\America\Argentina\Catamarca::class,
        'america/argentina/mendoza' => Zone\America\Argentina\Mendoza::class,
        'america/argentina/san_luis' => Zone\America\Argentina\SanLuis::class,
        'america/argentina/rio_gallegos' => Zone\America\Argentina\RioGallegos::class,
        'america/argentina/ushuaia' => Zone\America\Argentina\Ushuaia::class,
        'america/la_paz' => Zone\America\LaPaz::class,
        'america/noronha' => Zone\America\Noronha::class,
        'america/belem' => Zone\America\Belem::class,
        'america/santarem' => Zone\America\Santarem::class,
        'america/fortaleza' => Zone\America\Fortaleza::class,
        'america/recife' => Zone\America\Recife::class,
        'america/araguaina' => Zone\America\Araguaina::class,
        'america/maceio' => Zone\America\Maceio::class,
        'america/bahia' => Zone\America\Bahia::class,
        'america/sao_paulo' => Zone\America\SaoPaulo::class,
        'america/campo_grande' => Zone\America\CampoGrande::class,
        'america/cuiaba' => Zone\America\Cuiaba::class,
        'america/porto_velho' => Zone\America\PortoVelho::class,
        'america/boa_vista' => Zone\America\BoaVista::class,
        'america/manaus' => Zone\America\Manaus::class,
        'america/eirunepe' => Zone\America\Eirunepe::class,
        'america/rio_branco' => Zone\America\RioBranco::class,
        'america/santiago' => Zone\America\Santiago::class,
        'america/punta_arenas' => Zone\America\PuntaArenas::class,
        'pacific/easter' => Zone\Pacific\Easter::class,
        'antarctica/palmer' => Zone\Antarctica\Palmer::class,
        'america/bogota' => Zone\America\Bogota::class,
        'america/curacao' => Zone\America\Curacao::class,
        'america/guayaquil' => Zone\America\Guayaquil::class,
        'pacific/galapagos' => Zone\Pacific\Galapagos::class,
        'atlantic/stanley' => Zone\Atlantic\Stanley::class,
        'america/cayenne' => Zone\America\Cayenne::class,
        'america/guyana' => Zone\America\Guyana::class,
        'america/asuncion' => Zone\America\Asuncion::class,
        'america/lima' => Zone\America\Lima::class,
        'atlantic/south_georgia' => Zone\Atlantic\SouthGeorgia::class,
        'america/paramaribo' => Zone\America\Paramaribo::class,
        'america/port_of_spain' => Zone\America\PortofSpain::class,
        'america/montevideo' => Zone\America\Montevideo::class,
        'america/caracas' => Zone\America\Caracas::class,
        'etc/gmt' => Zone\Etc\GMT::class,
        'etc/utc' => Zone\Etc\UTC::class,
        'etc/uct' => Zone\Etc\UCT::class,
        'etc/gmt-14' => Zone\Etc\GMTMinus14::class,
        'etc/gmt-13' => Zone\Etc\GMTMinus13::class,
        'etc/gmt-12' => Zone\Etc\GMTMinus12::class,
        'etc/gmt-11' => Zone\Etc\GMTMinus11::class,
        'etc/gmt-10' => Zone\Etc\GMTMinus10::class,
        'etc/gmt-9' => Zone\Etc\GMTMinus9::class,
        'etc/gmt-8' => Zone\Etc\GMTMinus8::class,
        'etc/gmt-7' => Zone\Etc\GMTMinus7::class,
        'etc/gmt-6' => Zone\Etc\GMTMinus6::class,
        'etc/gmt-5' => Zone\Etc\GMTMinus5::class,
        'etc/gmt-4' => Zone\Etc\GMTMinus4::class,
        'etc/gmt-3' => Zone\Etc\GMTMinus3::class,
        'etc/gmt-2' => Zone\Etc\GMTMinus2::class,
        'etc/gmt-1' => Zone\Etc\GMTMinus1::class,
        'etc/gmt+1' => Zone\Etc\GMTPlus1::class,
        'etc/gmt+2' => Zone\Etc\GMTPlus2::class,
        'etc/gmt+3' => Zone\Etc\GMTPlus3::class,
        'etc/gmt+4' => Zone\Etc\GMTPlus4::class,
        'etc/gmt+5' => Zone\Etc\GMTPlus5::class,
        'etc/gmt+6' => Zone\Etc\GMTPlus6::class,
        'etc/gmt+7' => Zone\Etc\GMTPlus7::class,
        'etc/gmt+8' => Zone\Etc\GMTPlus8::class,
        'etc/gmt+9' => Zone\Etc\GMTPlus9::class,
        'etc/gmt+10' => Zone\Etc\GMTPlus10::class,
        'etc/gmt+11' => Zone\Etc\GMTPlus11::class,
        'etc/gmt+12' => Zone\Etc\GMTPlus12::class,
    ];
}
